@@ -2,8 +2,9 @@
   Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -44,6 +45,11 @@ bool AbstractGenericPlugin::hasConfigureDialog() const
     return false;
 }
 
+bool AbstractGenericPlugin::hasStatusBarSupport() const
+{
+    return false;
+}
+
 void AbstractGenericPlugin::showConfigureDialog(QWidget *parent)
 {
     Q_UNUSED(parent);
