@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,8 +24,6 @@ class PimCommon::AbstractGenericPluginInterfacePrivate
 {
 public:
     AbstractGenericPluginInterfacePrivate()
-        : plugin(nullptr)
-        , parentWidget(nullptr)
     {
     }
 
