@@ -2,8 +2,9 @@
   Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,6 +23,7 @@
 #include "pimcommon_private_export.h"
 namespace KPIMTextEdit {
 class PlainTextEditorWidget;
+class PlainTextEditor;
 }
 namespace PimCommon {
 class PIMCOMMON_TESTS_EXPORT LogActivitiesWidget : public QWidget
@@ -31,9 +33,10 @@ public:
     explicit LogActivitiesWidget(QWidget *parent = nullptr);
     ~LogActivitiesWidget();
     void setLog(const QString &str);
-    QString log() const;
+    Q_REQUIRED_RESULT QString log() const;
     void clear();
     void addLogEntry(const QString &entry);
+    Q_REQUIRED_RESULT KPIMTextEdit::PlainTextEditor *editor();
 Q_SIGNALS:
     void textChanged(bool changed);
 
